@@ -6,15 +6,15 @@
 // copied, modified, or distributed except according to those terms.
 
 mod add;
+mod advanced_record_filters;
 mod get;
-mod get_since;
 mod health_check;
 mod record_handlers;
 mod update;
 
 pub use add::*;
+pub use advanced_record_filters::*;
 pub use get::*;
-pub use get_since::*;
 pub use health_check::*;
 pub use record_handlers::*;
 pub use update::*;
